1
0
forked from pool/virtualbox

- Version bump to 6.0.4 (released January 28 2019 by Oracle)

Files "fixes_for_5.0" and "fixes_for_gcc9" are deleted - the code was fixed upstream.
This is a maintenance release. The following items were fixed and/or added:
Virtualization core: support Shanghai/Zhaoxin CPUs.
User interface: handle command line arguments to VirtualBox correctly (bugs #18206 and #18197)
User interface: improvements to machine manager window, virtual optical disk creator, storage selector window and log viewer window
User interface: various small fixes and improvements
Audio: implemented time scheduling for the AC'97 device emulation to keep audio and video in sync
Graphics: basic support for VMSVGA graphics device in virtual machines using EFI
Network: fix occasional NATNet crashes (bug #13899)
Network: worked around problems in certain PCnet drivers on old operating systems
Serial: fixed connecting to pseudo terminals on POSIX hosts (6.0.0 regression; bug #18319)
Linux hosts and guests: fix for building kernel modules against Linux 5.0. Thank you Kyle Laker

- Converted vboxwebsrv to a systemd service. Previously, this was started through init.d. bsc#1116050
  Files "vboxweb-service.service" and "vboxweb-service.sh" are added.
  File "vbox-vboxweb-init-script.diff" is removed.
  File "fixes_for_4.20.patch" is removed - the code was fixed upstream.
  File "fix_lib_search.patch" is added to fix the build of VBox0GL.
  File "fixes_for_5.0.patch" is added to compensate for API changes in kernel 5.0.
  File "virtualbox-system-x.patch" is removed.
  File "fixes_for_Leap15.1.patch" is added to fix build errors on Leap 15<F5>.1.
- Version bump to 6.0.2 (released January 15 2019 by Oracle)
This is a maintenance release. The following items were fixed and/or added:
User interface: fixed creation of desktop shortcuts for starting virtual machines (bug #18207)
User interface: allow the first run window to selecting host drives (bug #18230)
User interface: fixed attaching empty host optical drives (bug #18223)
User interface: implemented a new virtual optical disk creation window
USB: modified Linux backends to reset USB devices (previously, most guest attempts to reset USB devices were ignored)
PCnet: fixed a regression which caused some PCnet PCI guest drivers to not detect the emulated hardware (bug #18286)

OBS-URL: https://build.opensuse.org/package/show/Virtualization/virtualbox?expand=0&rev=465
This commit is contained in:
Larry Finger 2019-01-28 20:37:13 +00:00 committed by Git OBS Bridge
parent 1fecde2dfb
commit 6ef2a4ec60
29 changed files with 924 additions and 560 deletions

View File

@ -1,8 +1,8 @@
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
@@ -1237,7 +1237,11 @@ static Bool VBOXScreenInit(ScreenPtr pSc
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
@@ -1236,7 +1236,11 @@ static Bool VBOXScreenInit(ScreenPtr pSc
#endif
/* Register block and wake-up handlers for getting new screen size hints. */
@ -14,11 +14,11 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/vboxvideo.c
/* software cursor */
miDCInitialize(pScreen, xf86GetPointerScreenFuncs());
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/pointer.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/pointer.c
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
@@ -36,6 +36,10 @@
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/pointer.c
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/pointer.c
@@ -39,6 +39,10 @@
#include "cursorstr.h"
#include "servermd.h"
@ -29,11 +29,11 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
#include "vboxvideo.h"
#ifdef XORG_7X
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/edid.c
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/edid.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/edid.c
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/edid.c
@@ -36,6 +36,10 @@
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/edid.c
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/edid.c
@@ -35,6 +35,10 @@
* Michael Thayer <michael.thayer@oracle.com>
*/

View File

@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:71512fe7f20eab44ef00d36937a46ed0da51a3f1caa01e9fd4585e0bc7225ba9
size 4459021
oid sha256:073648489e87aeda24143a64b13e46f7d6231ff215d75715d16aec558890da0c
size 4326191

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:137cb45ec6203764d16b844aae5ffd07c29f0bd3c55005d905a957a60c5ad3fe
size 83356066

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:94903b78356081bc55d7a0689a31eb165e5b00e9de6a2663676240a24dadb673
size 118626165

View File

@ -1,10 +1,10 @@
Index: VirtualBox-5.2.20/src/VBox/Additions/linux/sharedfolders/utils.c
Index: VirtualBox-6.0.2/src/VBox/Additions/linux/sharedfolders/utils.c
===================================================================
--- VirtualBox-5.2.20.orig/src/VBox/Additions/linux/sharedfolders/utils.c
+++ VirtualBox-5.2.20/src/VBox/Additions/linux/sharedfolders/utils.c
@@ -49,11 +49,11 @@ static void sf_timespec_from_ftime(RTTIM
int64_t t = 1000000000 * *time;
RTTimeSpecSetNano(ts, t);
--- VirtualBox-6.0.2.orig/src/VBox/Additions/linux/sharedfolders/utils.c
+++ VirtualBox-6.0.2/src/VBox/Additions/linux/sharedfolders/utils.c
@@ -63,11 +63,11 @@ static void sf_timespec_from_ftime(RTTIM
int64_t t = 1000000000 * *time;
RTTimeSpecSetNano(ts, t);
}
-#else /* >= 2.6.0 */
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 18, 0)
@ -17,4 +17,4 @@ Index: VirtualBox-5.2.20/src/VBox/Additions/linux/sharedfolders/utils.c
+static void sf_ftime_from_timespec(struct timespec *tv, RTTIMESPEC *ts)
#endif
{
int64_t t = RTTimeSpecGetNano(ts);
int64_t t = RTTimeSpecGetNano(ts);

41
fix_lib_search.patch Normal file
View File

@ -0,0 +1,41 @@
Index: VirtualBox-6.0.2/configure
===================================================================
--- VirtualBox-6.0.2.orig/configure
+++ VirtualBox-6.0.2/configure
@@ -1538,14 +1538,14 @@ EOF
INCQT5="$q/include $q/include/QtCore"
FLGQT5="-DQT_SHARED"
I_INCQT5=`prefix_I "$INCQT5"`
- LIBQT5="-L$q/lib -lQt5CoreVBox"
+ LIBQT5="-L$q/lib -L$q/usr/lib64 -lQt5CoreVBox"
TOOLQT5="$q"
if test_compile "$LIBQT5 $LIBPTHREAD $I_INCQT5 $FLGQT5" qt5 qt5 nofatal &&
test_execute_path "`strip_L "$LIBQT5"`" nofatal; then
foundqt5=2 # internal
break;
fi
- LIBQT5="-L$q/lib -lQt5Core"
+ LIBQT5="-L$q/lib -L$q/usr/lib64 -lQt5Core"
if test_compile "$LIBQT5 $LIBPTHREAD $I_INCQT5 $FLGQT5" qt5 qt5 nofatal &&
test_execute_path "`strip_L "$LIBQT5"`" nofatal; then
foundqt5=1 # no pkg-config, Qt directory
Index: VirtualBox-6.0.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
===================================================================
--- VirtualBox-6.0.2.orig/src/VBox/Additions/common/crOpenGL/Makefile.kmk
+++ VirtualBox-6.0.2/src/VBox/Additions/common/crOpenGL/Makefile.kmk
@@ -217,15 +217,7 @@ VBoxOGL_LIBS.win += \
$(PATH_STAGE_LIB)/additions/VBoxCrHgsmi$(VBOX_SUFF_LIB)
if1of ($(KBUILD_TARGET), linux solaris freebsd)
- ifdef VBOX_USE_SYSTEM_GL_HEADERS
VBoxOGL_LIBS += Xcomposite Xdamage Xfixes Xext
- else
- VBoxOGL_LIBS += \
- $(PATH_STAGE_LIB)/libXcomposite.so \
- $(PATH_STAGE_LIB)/libXdamage.so \
- $(PATH_STAGE_LIB)/libXfixes.so \
- $(PATH_STAGE_LIB)/libXext.so
- endif
ifdef VBoxOGL_FAKEDRI
ifeq ($(KBUILD_TARGET), freebsd)
VBoxOGL_LIBS += \

View File

@ -1,145 +0,0 @@
Index: VirtualBox-5.2.22/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
+++ VirtualBox-5.2.22/src/VBox/HostDrivers/VBoxNetAdp/linux/VBoxNetAdp-linux.c
@@ -84,8 +84,11 @@ static long VBoxNetAdpLinuxIOCtlUnlocked
#endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36) */
static void vboxNetAdpEthGetDrvinfo(struct net_device *dev, struct ethtool_drvinfo *info);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+static int vboxNetAdpEthGetSettings(struct net_device *pNetDev, struct ethtool_link_ksettings *link_ksettings);
+#else
static int vboxNetAdpEthGetSettings(struct net_device *dev, struct ethtool_cmd *cmd);
-
+#endif
/*********************************************************************************************************************************
* Global Variables *
@@ -129,7 +132,11 @@ static struct miscdevice g_CtlDev =
static const struct ethtool_ops gEthToolOpsVBoxNetAdp =
{
.get_drvinfo = vboxNetAdpEthGetDrvinfo,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+ .get_link_ksettings = vboxNetAdpEthGetSettings,
+#else
.get_settings = vboxNetAdpEthGetSettings,
+#endif
.get_link = ethtool_op_get_link,
};
@@ -200,8 +207,18 @@ static void vboxNetAdpEthGetDrvinfo(stru
"N/A");
}
-
/* ethtool_ops::get_settings */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+static int vboxNetAdpEthGetSettings(struct net_device *pNetDev, struct ethtool_link_ksettings *link_ksettings)
+{
+ link_ksettings->link_modes.supported[0] = 0;
+ ethtool_link_ksettings_zero_link_mode(link_ksettings, advertising);
+ link_ksettings->base.speed = SPEED_10;
+ link_ksettings->base.duplex = DUPLEX_FULL;
+ link_ksettings->base.port = PORT_TP;
+ link_ksettings->base.phy_address = 0;
+ link_ksettings->base.autoneg = AUTONEG_DISABLE;
+#else
static int vboxNetAdpEthGetSettings(struct net_device *pNetDev, struct ethtool_cmd *cmd)
{
cmd->supported = 0;
@@ -218,6 +235,7 @@ static int vboxNetAdpEthGetSettings(stru
cmd->autoneg = AUTONEG_DISABLE;
cmd->maxtxpkt = 0;
cmd->maxrxpkt = 0;
+#endif
return 0;
}
Index: VirtualBox-5.2.22/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c
+++ VirtualBox-5.2.22/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c
@@ -171,11 +171,19 @@ RTDECL(PRTTIMESPEC) RTTimeNow(PRTTIMESPE
{
IPRT_LINUX_SAVE_EFL_AC();
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 16)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+ struct timespec64 Ts;
+ ktime_get_real_ts64(&Ts);
+#else
struct timespec Ts;
ktime_get_real_ts(&Ts);
+#endif
IPRT_LINUX_RESTORE_EFL_AC();
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+ return RTTimeSpecSetTimespec64(pTime, &Ts);
+#else
return RTTimeSpecSetTimespec(pTime, &Ts);
-
+#endif
#else /* < 2.6.16 */
struct timeval Tv;
do_gettimeofday(&Tv);
Index: VirtualBox-5.2.22/include/iprt/time.h
===================================================================
--- VirtualBox-5.2.22.orig/include/iprt/time.h
+++ VirtualBox-5.2.22/include/iprt/time.h
@@ -54,7 +54,6 @@ typedef struct RTTIMESPEC
int64_t i64NanosecondsRelativeToUnixEpoch;
} RTTIMESPEC;
-
/** @name RTTIMESPEC methods
* @{ */
@@ -388,6 +387,7 @@ DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTim
{
return RTTimeSpecAddMicro(RTTimeSpecSetSeconds(pTime, pTimeval->tv_sec), pTimeval->tv_usec);
}
+
#endif /* various ways of detecting struct timeval */
@@ -427,6 +427,25 @@ DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTim
{
return RTTimeSpecAddNano(RTTimeSpecSetSeconds(pTime, pTimespec->tv_sec), pTimespec->tv_nsec);
}
+
+#ifndef _LINUX_TIME64_H
+/* With kernel 4.20+, the second argument of time routines change from
+ * struct timespec to struct timespec64. This file is built twice, once
+ * in user mode, and once in kernel mode. In user mode, the struct is
+ * undefined, thus the following definition is provided. The guard macro
+ * from the kernels include/linux/time64.h is _LINUX_TIME64_H, thus
+ * the definition of that macro determines whether the struct is defined.
+ */
+struct timespec64 {
+ long long tv_sec; /* seconds */
+ long tv_nsec; /* nanoseconds */
+};
+#endif
+
+DECLINLINE(PRTTIMESPEC) RTTimeSpecSetTimespec64(PRTTIMESPEC pTime, const struct timespec64 *pTimeval)
+{
+ return RTTimeSpecAddMicro(RTTimeSpecSetSeconds(pTime, pTimeval->tv_sec), 1000 * pTimeval->tv_nsec);
+}
#endif /* various ways of detecting struct timespec */
Index: VirtualBox-5.2.22/src/VBox/Additions/linux/drm/vbox_fb.c
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Additions/linux/drm/vbox_fb.c
+++ VirtualBox-5.2.22/src/VBox/Additions/linux/drm/vbox_fb.c
@@ -297,8 +297,12 @@ static int vboxfb_create(struct drm_fb_h
* The last flag forces a mode set on VT switches even if the kernel
* does not think it is needed.
*/
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 20, 0)
+ info->flags = FBINFO_DEFAULT | FBINFO_MISC_ALWAYS_SETPAR;
+#else
info->flags = FBINFO_DEFAULT | FBINFO_CAN_FORCE_OUTPUT |
FBINFO_MISC_ALWAYS_SETPAR;
+#endif
info->fbops = &vboxfb_ops;
ret = fb_alloc_cmap(&info->cmap, 256, 0);

17
fixes_for_Leap15.1.patch Normal file
View File

@ -0,0 +1,17 @@
Index: VirtualBox-5.2.24/src/VBox/Additions/linux/drm/vbox_drv.c
===================================================================
--- VirtualBox-5.2.24.orig/src/VBox/Additions/linux/drm/vbox_drv.c
+++ VirtualBox-5.2.24/src/VBox/Additions/linux/drm/vbox_drv.c
@@ -264,12 +264,6 @@ static struct drm_driver driver = {
.lastclose = vbox_driver_lastclose,
.master_set = vbox_master_set,
.master_drop = vbox_master_drop,
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 18, 0) || defined(RHEL_73)
-# if LINUX_VERSION_CODE < KERNEL_VERSION(4, 14, 0) && !defined(RHEL_75)
- .set_busid = drm_pci_set_busid,
-# endif
-#endif
-
.fops = &vbox_fops,
.irq_handler = vbox_irq_handler,
.name = DRIVER_NAME,

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.14/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
Index: VirtualBox-6.0.2/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
===================================================================
--- VirtualBox-5.2.14.orig/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
+++ VirtualBox-5.2.14/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
--- VirtualBox-6.0.2.orig/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
+++ VirtualBox-6.0.2/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
@@ -83,6 +83,7 @@
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicslayoutitem.h>
@ -10,15 +10,15 @@ Index: VirtualBox-5.2.14/src/VBox/Frontends/VirtualBox/src/precomp_vcc.h
#include <QtCore/QMetaType>
#include <QtGui/qevent.h>
#include <QtGui/qtouchdevice.h>
Index: VirtualBox-5.2.14/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
Index: VirtualBox-6.0.2/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
===================================================================
--- VirtualBox-5.2.14.orig/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
+++ VirtualBox-5.2.14/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
@@ -22,6 +22,7 @@
--- VirtualBox-6.0.2.orig/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
+++ VirtualBox-6.0.2/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsProxy.cpp
@@ -18,6 +18,7 @@
/* Qt includes: */
# include <QButtonGroup>
# include <QRegExpValidator>
#include <QButtonGroup>
#include <QRegExpValidator>
+#include <QButtonGroup>
/* GUI includes: */
# include "QIWidgetValidator.h"
#include "QIWidgetValidator.h"

View File

@ -1,26 +0,0 @@
Index: VirtualBox-5.2.22/src/VBox/Runtime/r3/linux/semevent-linux.cpp
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Runtime/r3/linux/semevent-linux.cpp
+++ VirtualBox-5.2.22/src/VBox/Runtime/r3/linux/semevent-linux.cpp
@@ -37,7 +37,7 @@
* against glibc < 2.6.
*/
#include "../posix/semevent-posix.cpp"
-asm volatile (".global epoll_pwait");
+asm (".global epoll_pwait");
#else /* glibc < 2.6 */
Index: VirtualBox-5.2.22/src/VBox/Runtime/r3/linux/semeventmulti-linux.cpp
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Runtime/r3/linux/semeventmulti-linux.cpp
+++ VirtualBox-5.2.22/src/VBox/Runtime/r3/linux/semeventmulti-linux.cpp
@@ -39,7 +39,7 @@
* against glibc < 2.6.
*/
#include "../posix/semeventmulti-posix.cpp"
-asm volatile (".global epoll_pwait");
+asm (".global epoll_pwait");
#else /* glibc < 2.6 */

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
@@ -23,6 +23,9 @@ vboxvideo_70_DEFS := \
ifeq ($(KBUILD_TARGET),solaris) # don't use .solaris or anything here.
vboxvideo_70_DEFS += __EXTENSIONS__ ## @todo Why this?
@ -12,11 +12,11 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
vboxvideo_13_DEFS := $(vboxvideo_70_DEFS) VBOXVIDEO_13
vboxvideo_15_DEFS := \
$(vboxvideo_13_DEFS) NO_ANSIC PCIACCESS XSERVER_LIBPCIACCESS _XORG_SERVER_H_ _DIX_CONFIG_H_
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/edid.c
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/edid.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/edid.c
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/edid.c
@@ -36,10 +36,6 @@
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/edid.c
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/edid.c
@@ -35,10 +35,6 @@
* Michael Thayer <michael.thayer@oracle.com>
*/
@ -27,11 +27,11 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/edid.c
#include "misc.h"
#include "xf86DDC.h"
#include "xf86Crtc.h"
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/pointer.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/pointer.c
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
@@ -36,10 +36,6 @@
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/pointer.c
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/pointer.c
@@ -39,10 +39,6 @@
#include "cursorstr.h"
#include "servermd.h"
@ -42,13 +42,13 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/pointer.c
#include "vboxvideo.h"
#ifdef XORG_7X
Index: VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
Index: VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
+++ VirtualBox-5.2.0/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
--- VirtualBox-6.0.2.orig/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
+++ VirtualBox-6.0.2/src/VBox/Additions/x11/vboxvideo/vboxvideo.h
@@ -42,8 +42,8 @@
#ifndef _VBOXVIDEO_H_
#define _VBOXVIDEO_H_
# pragma once
#endif
-#include <VBoxVideoGuest.h>
-#include <VBoxVideo.h>

View File

@ -1,10 +1,10 @@
Index: VirtualBox-5.2.0/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
Index: VirtualBox-6.0.2/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
+++ VirtualBox-5.2.0/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
--- VirtualBox-6.0.2.orig/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
+++ VirtualBox-6.0.2/src/VBox/Runtime/r0drv/linux/alloc-r0drv-linux.c
@@ -35,7 +35,7 @@
#include <iprt/assert.h>
#include <iprt/err.h>
#include <iprt/errcore.h>
#include "r0drv/alloc-r0drv.h"
-
+#include <linux/kmemleak.h>

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.4/Makefile.kmk
Index: VirtualBox-5.2.24/Makefile.kmk
===================================================================
--- VirtualBox-5.2.4.orig/Makefile.kmk
+++ VirtualBox-5.2.4/Makefile.kmk
--- VirtualBox-5.2.24.orig/Makefile.kmk
+++ VirtualBox-5.2.24/Makefile.kmk
@@ -701,7 +701,6 @@ VBOX_CORE_DOXYFILE_INPUT_DIRS = \
src/VBox/Additions/x11/vboxmouse \
src/VBox/Additions/x11/vboxmouse/xorg70 \
@ -10,11 +10,11 @@ Index: VirtualBox-5.2.4/Makefile.kmk
src/VBox/NetworkServices \
src/VBox/NetworkServices/DHCP \
src/VBox/NetworkServices/NAT \
Index: VirtualBox-5.2.4/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
Index: VirtualBox-5.2.24/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
===================================================================
--- VirtualBox-5.2.4.orig/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
+++ VirtualBox-5.2.4/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
@@ -395,7 +395,8 @@ vboxvideo_drv_118_INCS += $(PATH_ROOT)/s
--- VirtualBox-5.2.24.orig/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
+++ VirtualBox-5.2.24/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
@@ -398,7 +398,8 @@ vboxvideo_drv_118_INCS += $(PATH_ROOT)/s
vboxvideo_drv_118_SOURCES := $(vboxvideo_drv_17_SOURCES)
vboxvideo_drv_118_LIBS += $(vboxvideo_drv_70_LIBS)
@ -24,10 +24,10 @@ Index: VirtualBox-5.2.4/src/VBox/Additions/x11/vboxvideo/Makefile.kmk
# Build using local X.Org headers. We assume X.Org Server 1.7 or later.
DLLS := $(filter-out vboxvideo_drv_%,$(DLLS)) vboxvideo_drv_system
SYSMODS := $(filter-out vboxvideo_drv%,$(SYSMODS))
Index: VirtualBox-5.2.4/src/VBox/Additions/x11/Makefile.kmk
Index: VirtualBox-5.2.24/src/VBox/Additions/x11/Makefile.kmk
===================================================================
--- VirtualBox-5.2.4.orig/src/VBox/Additions/x11/Makefile.kmk
+++ VirtualBox-5.2.4/src/VBox/Additions/x11/Makefile.kmk
--- VirtualBox-5.2.24.orig/src/VBox/Additions/x11/Makefile.kmk
+++ VirtualBox-5.2.24/src/VBox/Additions/x11/Makefile.kmk
@@ -22,7 +22,7 @@ include $(KBUILD_PATH)/subheader.kmk
if1of ($(KBUILD_TARGET), freebsd linux netbsd openbsd solaris)
include $(PATH_SUB_CURRENT)/VBoxClient/Makefile.kmk

View File

@ -1,8 +1,8 @@
Index: b/configure
Index: VirtualBox-6.0.2/configure
===================================================================
--- a/configure
+++ b/configure
@@ -1963,17 +1963,17 @@ extern "C" int main(void)
--- VirtualBox-6.0.2.orig/configure
+++ VirtualBox-6.0.2/configure
@@ -1969,17 +1969,17 @@ extern "C" int main(void)
{
Py_Initialize();
printf("found version %s", PY_VERSION);
@ -23,11 +23,11 @@ Index: b/configure
for p in $PYTHONDIR; do
for d in $SUPPYTHONLIBS; do
for b in lib/x86_64-linux-gnu lib/i386-linux-gnu lib64 lib/64 lib; do
Index: b/src/VBox/Installer/linux/routines.sh
Index: VirtualBox-6.0.2/src/VBox/Installer/linux/routines.sh
===================================================================
--- a/src/VBox/Installer/linux/routines.sh
+++ b/src/VBox/Installer/linux/routines.sh
@@ -375,8 +375,8 @@ terminate_proc() {
--- VirtualBox-6.0.2.orig/src/VBox/Installer/linux/routines.sh
+++ VirtualBox-6.0.2/src/VBox/Installer/linux/routines.sh
@@ -391,8 +391,8 @@ terminate_proc() {
maybe_run_python_bindings_installer() {
VBOX_INSTALL_PATH="${1}"
@ -38,11 +38,11 @@ Index: b/src/VBox/Installer/linux/routines.sh
if sys.version_info >= (2, 6):
print \"test\"' 2> /dev/null`" != "test" ]; then
echo 1>&2 "Python 2.6 or later not available, skipping bindings installation."
Index: b/src/bldprogs/scm.cpp
Index: VirtualBox-6.0.2/src/bldprogs/scm.cpp
===================================================================
--- a/src/bldprogs/scm.cpp
+++ b/src/bldprogs/scm.cpp
@@ -2033,7 +2033,7 @@ static int scmProcessFileInner(PSCMRWSTA
--- VirtualBox-6.0.2.orig/src/bldprogs/scm.cpp
+++ VirtualBox-6.0.2/src/bldprogs/scm.cpp
@@ -2206,7 +2206,7 @@ static int scmProcessFileInner(PSCMRWSTA
pszTreatAs = "shell";
else if ( (cchFirst >= 15 && strncmp(pchFirst, "/usr/bin/python", 15) == 0)
|| (cchFirst >= 19 && strncmp(pchFirst, "/usr/bin/env python", 19) == 0) )
@ -51,10 +51,10 @@ Index: b/src/bldprogs/scm.cpp
else if ( (cchFirst >= 13 && strncmp(pchFirst, "/usr/bin/perl", 13) == 0)
|| (cchFirst >= 17 && strncmp(pchFirst, "/usr/bin/env perl", 17) == 0) )
pszTreatAs = "perl";
Index: b/src/libs/libxml2-2.9.4/configure
Index: VirtualBox-6.0.2/src/libs/libxml2-2.9.4/configure
===================================================================
--- a/src/libs/libxml2-2.9.4/configure
+++ b/src/libs/libxml2-2.9.4/configure
--- VirtualBox-6.0.2.orig/src/libs/libxml2-2.9.4/configure
+++ VirtualBox-6.0.2/src/libs/libxml2-2.9.4/configure
@@ -15153,10 +15153,10 @@ PYTHON_SITE_PACKAGES=
PYTHON_TESTS=
pythondir=
@ -79,11 +79,11 @@ Index: b/src/libs/libxml2-2.9.4/configure
{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
$as_echo_n "checking for $ac_word... " >&6; }
if ${ac_cv_path_PYTHON+:} false; then :
Index: b/src/VBox/ValidationKit/testboxscript/setup.sh
Index: VirtualBox-6.0.2/src/VBox/ValidationKit/testboxscript/setup.sh
===================================================================
--- a/src/VBox/ValidationKit/testboxscript/setup.sh
+++ b/src/VBox/ValidationKit/testboxscript/setup.sh
@@ -644,7 +644,7 @@ import sys;\
--- VirtualBox-6.0.2.orig/src/VBox/ValidationKit/testboxscript/setup.sh
+++ VirtualBox-6.0.2/src/VBox/ValidationKit/testboxscript/setup.sh
@@ -652,7 +652,7 @@ import sys;\
x = sys.version_info[0] == 2 and (sys.version_info[1] >= 6 or (sys.version_info[1] == 5 and sys.version_info[2] >= 1));\
sys.exit(not x);\
";
@ -92,10 +92,10 @@ Index: b/src/VBox/ValidationKit/testboxscript/setup.sh
do
python=`which ${python} 2> /dev/null`
if [ -n "${python}" -a -x "${python}" ]; then
Index: b/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
Index: VirtualBox-6.0.2/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
===================================================================
--- a/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
+++ b/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
--- VirtualBox-6.0.2.orig/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
+++ VirtualBox-6.0.2/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
@@ -20,7 +20,7 @@
%define %PYTHON% 1
%define VBOXDOCDIR %{_defaultdocdir}/%NAME%
@ -105,7 +105,7 @@ Index: b/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
Summary: Oracle VM VirtualBox
Name: %NAME%
@@ -82,7 +82,7 @@ install -m 755 -d $RPM_BUILD_ROOT/usr/sh
@@ -89,7 +89,7 @@ install -m 755 -d $RPM_BUILD_ROOT/usr/sh
%if %{?with_python:1}%{!?with_python:0}
(export VBOX_INSTALL_PATH=/usr/lib/virtualbox && \
cd ./sdk/installer && \
@ -114,10 +114,10 @@ Index: b/src/VBox/Installer/linux/rpm/VirtualBox.tmpl.spec
%endif
rm -rf sdk/installer
mv nls $RPM_BUILD_ROOT/usr/share/virtualbox
Index: b/src/libs/libxml2-2.9.4/libxml.spec.in
Index: VirtualBox-6.0.2/src/libs/libxml2-2.9.4/libxml.spec.in
===================================================================
--- a/src/libs/libxml2-2.9.4/libxml.spec.in
+++ b/src/libs/libxml2-2.9.4/libxml.spec.in
--- VirtualBox-6.0.2.orig/src/libs/libxml2-2.9.4/libxml.spec.in
+++ VirtualBox-6.0.2/src/libs/libxml2-2.9.4/libxml.spec.in
@@ -101,11 +101,11 @@ rm -fr %{buildroot}
make install DESTDIR=%{buildroot}
@ -133,10 +133,10 @@ Index: b/src/libs/libxml2-2.9.4/libxml.spec.in
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
Index: b/src/libs/libxml2-2.9.4/libxml2.spec
Index: VirtualBox-6.0.2/src/libs/libxml2-2.9.4/libxml2.spec
===================================================================
--- a/src/libs/libxml2-2.9.4/libxml2.spec
+++ b/src/libs/libxml2-2.9.4/libxml2.spec
--- VirtualBox-6.0.2.orig/src/libs/libxml2-2.9.4/libxml2.spec
+++ VirtualBox-6.0.2/src/libs/libxml2-2.9.4/libxml2.spec
@@ -103,7 +103,7 @@ make install DESTDIR=%{buildroot}
%if 0%{?with_python3}
@ -146,26 +146,23 @@ Index: b/src/libs/libxml2-2.9.4/libxml2.spec
make install DESTDIR=%{buildroot}
%endif # with_python3
Index: b/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
Index: VirtualBox-6.0.2/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
===================================================================
--- a/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
+++ b/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
@@ -439,8 +439,10 @@ char *PyTraceback_AsString(PyObject *exc
--- VirtualBox-6.0.2.orig/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
+++ VirtualBox-6.0.2/src/libs/xpcom18a4/python/src/ErrorUtils.cpp
@@ -439,6 +439,8 @@ char *PyTraceback_AsString(PyObject *exc
{ // a temp scope so I can use temp locals.
#if PY_MAJOR_VERSION <= 2
char *tempResult = PyString_AsString(obResult);
-#else
+#elif PY_MINOR_VERSION <= 6
char *tempResult = PyUnicode_AsUTF8(obResult);
+#else
+ const char *tempResult = PyUnicode_AsUTF8(obResult);
#endif
result = (char *)PyMem_Malloc(strlen(tempResult)+1);
if (result==NULL)
Index: b/src/libs/xpcom18a4/python/src/PyGBase.cpp
+ char *tempResult = PyUnicode_AsUTF8(obResult);
#else
/* PyUnicode_AsUTF8() is const char * as of Python 3.7, char * earlier. */
const char *tempResult = (const char *)PyUnicode_AsUTF8(obResult);
Index: VirtualBox-6.0.2/src/libs/xpcom18a4/python/src/PyGBase.cpp
===================================================================
--- a/src/libs/xpcom18a4/python/src/PyGBase.cpp
+++ b/src/libs/xpcom18a4/python/src/PyGBase.cpp
--- VirtualBox-6.0.2.orig/src/libs/xpcom18a4/python/src/PyGBase.cpp
+++ VirtualBox-6.0.2/src/libs/xpcom18a4/python/src/PyGBase.cpp
@@ -183,7 +183,11 @@ PyG_Base::~PyG_Base()
// Get the correct interface pointer for this object given the IID.
void *PyG_Base::ThisAsIID( const nsIID &iid )

View File

@ -1,16 +1,16 @@
Index: VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
Index: VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
+++ VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -327,15 +327,15 @@ void UINameAndSystemEditor::sltFamilyCha
Index: VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
Index: VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
+++ VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
--- VirtualBox-6.0.0.orig/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
+++ VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlobalSettingsUpdate.cpp
@@ -110,8 +110,8 @@ void UIGlobalSettingsUpdate::getFromCach
/* Get old update data from the cache: */
const UIDataSettingsGlobalUpdate &oldUpdateData = m_pCache->base();
@ -13,11 +13,20 @@ Index: VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/global/UIGlob
if (m_pCheckBoxUpdate->isChecked())
{
m_pComboBoxUpdatePeriod->setCurrentIndex(oldUpdateData.m_periodIndex);
Index: VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
Index: VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
+++ VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
@@ -103,16 +103,6 @@ UISettingsDialogGlobal::UISettingsDialog
--- VirtualBox-6.0.0.orig/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
+++ VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDialogSpecific.cpp
@@ -91,8 +91,6 @@ void UISettingsDialogGlobal::retranslate
m_pSelector->setItemText(GlobalSettingsPageType_Input, tr("Input"));
#ifdef VBOX_GUI_WITH_NETWORK_MANAGER
- /* Update page: */
- m_pSelector->setItemText(GlobalSettingsPageType_Update, tr("Update"));
#endif
/* Language page: */
@@ -208,16 +206,6 @@ void UISettingsDialogGlobal::prepare()
iPageIndex, "#input", pSettingsPage);
break;
}
@ -34,12 +43,3 @@ Index: VirtualBox-5.2.0/src/VBox/Frontends/VirtualBox/src/settings/UISettingsDia
/* Language page: */
case GlobalSettingsPageType_Language:
{
@@ -248,8 +238,6 @@ void UISettingsDialogGlobal::retranslate
m_pSelector->setItemText(GlobalSettingsPageType_Input, tr("Input"));
#ifdef VBOX_GUI_WITH_NETWORK_MANAGER
- /* Update page: */
- m_pSelector->setItemText(GlobalSettingsPageType_Update, tr("Update"));
#endif /* VBOX_GUI_WITH_NETWORK_MANAGER */
/* Language page: */

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.0/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
Index: VirtualBox-6.0.0/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
+++ VirtualBox-5.2.0/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
--- VirtualBox-6.0.0.orig/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
+++ VirtualBox-6.0.0/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
@@ -62,7 +62,7 @@ int main(int argc, char *argv[])
printf("VirtualBox DirectFB GUI built %s %s\n"
@ -11,10 +11,10 @@ Index: VirtualBox-5.2.0/src/VBox/Frontends/VBoxFB/VBoxFB.cpp
for (;;)
{
Index: VirtualBox-5.2.0/src/VBox/Runtime/common/string/uniread.cpp
Index: VirtualBox-6.0.0/src/VBox/Runtime/common/string/uniread.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Runtime/common/string/uniread.cpp
+++ VirtualBox-5.2.0/src/VBox/Runtime/common/string/uniread.cpp
--- VirtualBox-6.0.0.orig/src/VBox/Runtime/common/string/uniread.cpp
+++ VirtualBox-6.0.0/src/VBox/Runtime/common/string/uniread.cpp
@@ -1036,7 +1036,7 @@ int PrintHeader(const char *argv0, const
" * IPRT - Unicode Tables.\n"
" *\n"
@ -24,10 +24,10 @@ Index: VirtualBox-5.2.0/src/VBox/Runtime/common/string/uniread.cpp
" */\n"
"\n"
"/*\n"
Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
===================================================================
--- VirtualBox-5.2.0.orig/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
+++ VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
@@ -42,16 +42,13 @@
/**************************IDENTITY AND VERSIONING***********************/
/************************************************************************/
@ -50,10 +50,10 @@ Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/libc/src/plvrsion.c
#if !defined(_PRODUCTION)
#define _PRODUCTION ""
#endif
Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
===================================================================
--- VirtualBox-5.2.0.orig/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
+++ VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
@@ -44,16 +44,10 @@
#ifndef XP_MAC
#include "_pr_bld.h"
@ -73,10 +73,10 @@ Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/pr/src/prvrsion.c
#if !defined(_PRODUCTION)
#define _PRODUCTION ""
#endif
Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
===================================================================
--- VirtualBox-5.2.0.orig/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
+++ VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
@@ -42,16 +42,13 @@
/**************************IDENTITY AND VERSIONING***********************/
/************************************************************************/
@ -99,10 +99,10 @@ Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/prstreams/plvrsion.c
#if !defined(_PRODUCTION)
#define _PRODUCTION ""
#endif
Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
===================================================================
--- VirtualBox-5.2.0.orig/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
+++ VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
@@ -42,16 +42,13 @@
/**************************IDENTITY AND VERSIONING***********************/
/************************************************************************/
@ -125,11 +125,11 @@ Index: VirtualBox-5.2.0/src/libs/xpcom18a4/nsprpub/lib/ds/plvrsion.c
#if !defined(_PRODUCTION)
#define _PRODUCTION ""
#endif
Index: VirtualBox-5.2.0/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
Index: VirtualBox-6.0.0/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
+++ VirtualBox-5.2.0/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
@@ -148,7 +148,7 @@ static int vboxInitLogging(const char *p
--- VirtualBox-6.0.0.orig/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
+++ VirtualBox-6.0.0/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTestApp.cpp
@@ -147,7 +147,7 @@ static int vboxInitLogging(const char *p
#endif
"Log opened %s\n",
VBOX_VERSION_STRING, RTBldCfgRevision(), VBOX_BUILD_TARGET,
@ -138,11 +138,11 @@ Index: VirtualBox-5.2.0/src/VBox/HostServices/SharedOpenGL/OpenGLTest/OpenGLTest
vrc = RTSystemQueryOSInfo(RTSYSOSINFO_PRODUCT, szTmp, sizeof(szTmp));
if (RT_SUCCESS(vrc) || vrc == VERR_BUFFER_OVERFLOW)
Index: VirtualBox-5.2.0/src/VBox/Devices/PC/BIOS/bios.c
Index: VirtualBox-6.0.0/src/VBox/Devices/PC/BIOS/bios.c
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Devices/PC/BIOS/bios.c
+++ VirtualBox-5.2.0/src/VBox/Devices/PC/BIOS/bios.c
@@ -159,7 +159,7 @@ void set_mode(uint8_t mode);
--- VirtualBox-6.0.0.orig/src/VBox/Devices/PC/BIOS/bios.c
+++ VirtualBox-6.0.0/src/VBox/Devices/PC/BIOS/bios.c
@@ -143,7 +143,7 @@ void set_mode(uint8_t mode);
#define BX_PCIBIOS 1
#define BX_APPNAME "VirtualBox"
@ -151,10 +151,10 @@ Index: VirtualBox-5.2.0/src/VBox/Devices/PC/BIOS/bios.c
//--------------------------------------------------------------------------
// print_bios_banner
// displays a the bios version
Index: VirtualBox-5.2.0/src/VBox/Additions/common/VBoxService/VBoxService.cpp
Index: VirtualBox-6.0.0/src/VBox/Additions/common/VBoxService/VBoxService.cpp
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Additions/common/VBoxService/VBoxService.cpp
+++ VirtualBox-5.2.0/src/VBox/Additions/common/VBoxService/VBoxService.cpp
--- VirtualBox-6.0.0.orig/src/VBox/Additions/common/VBoxService/VBoxService.cpp
+++ VirtualBox-6.0.0/src/VBox/Additions/common/VBoxService/VBoxService.cpp
@@ -242,7 +242,7 @@ static DECLCALLBACK(void) vgsvcLogHeader
"VBoxService %s r%s (verbosity: %u) %s (%s %s) release log\n"
"Log opened %s\n",
@ -164,3 +164,235 @@ Index: VirtualBox-5.2.0/src/VBox/Additions/common/VBoxService/VBoxService.cpp
int vrc = RTSystemQueryOSInfo(RTSYSOSINFO_PRODUCT, szTmp, sizeof(szTmp));
if (RT_SUCCESS(vrc) || vrc == VERR_BUFFER_OVERFLOW)
Index: VirtualBox-6.0.0/src/VBox/ExtPacks/BusMouseSample/Makefile.kmk
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/ExtPacks/BusMouseSample/Makefile.kmk
+++ VirtualBox-6.0.0/src/VBox/ExtPacks/BusMouseSample/Makefile.kmk
@@ -187,7 +187,7 @@ $(VBOX_PATH_PACKAGES)/$(VBOX_BUSMOUSE_MA
$(VBoxBusMouseIns_0_OUTDIR)/Stage/ExtPack.manifest \
$(VBoxBusMouseIns_0_OUTDIR)/Stage/ExtPack.signature
# Tar it up.
- tar -cvf - -C $(VBoxBusMouseIns_0_OUTDIR)/Stage/ . | gzip -9c > $@
+ tar -cvf - -C $(VBoxBusMouseIns_0_OUTDIR)/Stage/ . | gzip -9nc > $@
# Clean up
$(RM) -Rf $(VBoxBusMouseIns_0_OUTDIR)/Stage/
Index: VirtualBox-6.0.0/src/VBox/ExtPacks/Skeleton/Makefile.kmk
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/ExtPacks/Skeleton/Makefile.kmk
+++ VirtualBox-6.0.0/src/VBox/ExtPacks/Skeleton/Makefile.kmk
@@ -161,7 +161,7 @@ $(VBOX_PATH_PACKAGES)/$(VBOX_SKELETON_MA
$(VBoxSkeletonIns_0_OUTDIR)/Stage/ExtPack.manifest \
$(VBoxSkeletonIns_0_OUTDIR)/Stage/ExtPack.signature
# Tar it up.
- tar -cvf - -C $(VBoxSkeletonIns_0_OUTDIR)/Stage/ . | gzip -9c > $@
+ tar -cvf - -C $(VBoxSkeletonIns_0_OUTDIR)/Stage/ . | gzip -9nc > $@
# Clean up
$(RM) -Rf $(VBoxSkeletonIns_0_OUTDIR)/Stage/
Index: VirtualBox-6.0.0/src/VBox/ExtPacks/VBoxDTrace/Makefile.kmk
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/ExtPacks/VBoxDTrace/Makefile.kmk
+++ VirtualBox-6.0.0/src/VBox/ExtPacks/VBoxDTrace/Makefile.kmk
@@ -342,7 +342,7 @@ if defined(VBOX_WITH_EXTPACK_VBOXDTRACE)
$(VBoxDTraceIns_0_OUTDIR)/Stage/ExtPack.manifest \
$(VBoxDTraceIns_0_OUTDIR)/Stage/ExtPack.signature
# Tar it up.
- tar -cvf - -C $(VBoxDTraceIns_0_OUTDIR)/Stage/ . | gzip -9c > $@
+ tar -cvf - -C $(VBoxDTraceIns_0_OUTDIR)/Stage/ . | gzip -9nc > $@
# Clean up
$(RM) -Rf $(VBoxDTraceIns_0_OUTDIR)/Stage/
Index: VirtualBox-6.0.0/src/VBox/ExtPacks/VNC/Makefile.kmk
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/ExtPacks/VNC/Makefile.kmk
+++ VirtualBox-6.0.0/src/VBox/ExtPacks/VNC/Makefile.kmk
@@ -154,7 +154,7 @@ $(VBOX_PATH_PACKAGES)/$(VBOX_VNC_MANGLED
$(VBoxVNCIns_0_OUTDIR)/Stage/ExtPack.manifest \
$(VBoxVNCIns_0_OUTDIR)/Stage/ExtPack.signature
# Tar it up.
- tar -cvf - -C $(VBoxVNCIns_0_OUTDIR)/Stage/ . | gzip -9c > $@
+ tar -cvf - -C $(VBoxVNCIns_0_OUTDIR)/Stage/ . | gzip -9nc > $@
# Clean up
$(RM) -Rf $(VBoxVNCIns_0_OUTDIR)/Stage/
Index: VirtualBox-6.0.0/src/VBox/Additions/common/VBoxGuest/VBoxGuest-win.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Additions/common/VBoxGuest/VBoxGuest-win.cpp
+++ VirtualBox-6.0.0/src/VBox/Additions/common/VBoxGuest/VBoxGuest-win.cpp
@@ -316,7 +316,7 @@ NTSTATUS DriverEntry(PDRIVER_OBJECT pDrv
}
VGDrvCommonInitLoggers();
- LogFunc(("Driver built: %s %s\n", __DATE__, __TIME__));
+ LogFunc(("Driver built: %s %s\n", "no date", "no time"));
/*
* Check if the NT version is supported and initialize g_enmVGDrvNtVer.
Index: VirtualBox-6.0.0/src/VBox/Additions/linux/lightdm-greeter/vbox-greeter.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Additions/linux/lightdm-greeter/vbox-greeter.cpp
+++ VirtualBox-6.0.0/src/VBox/Additions/linux/lightdm-greeter/vbox-greeter.cpp
@@ -872,7 +872,7 @@ static DECLCALLBACK(void) vboxGreeterLog
"vbox-greeter %s r%s (verbosity: %d) %s (%s %s) release log\n"
"Log opened %s\n",
RTBldCfgVersion(), RTBldCfgRevisionStr(), g_iVerbosity, VBOX_BUILD_TARGET,
- __DATE__, __TIME__, szTmp);
+ "no date", "no time", szTmp);
int vrc = RTSystemQueryOSInfo(RTSYSOSINFO_PRODUCT, szTmp, sizeof(szTmp));
if (RT_SUCCESS(vrc) || vrc == VERR_BUFFER_OVERFLOW)
Index: VirtualBox-6.0.0/src/VBox/Additions/solaris/Mouse/vboxms.c
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Additions/solaris/Mouse/vboxms.c
+++ VirtualBox-6.0.0/src/VBox/Additions/solaris/Mouse/vboxms.c
@@ -256,7 +256,7 @@ static VBMSSTATE g_OpenNodeSt
int _init(void)
{
int rc;
- LogRelFlow((DEVICE_NAME ": built on " __DATE__ " at " __TIME__ "\n"));
+ LogRelFlow((DEVICE_NAME ": built on " "no date" " at " "no time" "\n"));
mutex_init(&g_OpenNodeState.InitMtx, NULL, MUTEX_DRIVER, NULL);
/*
* Prevent module autounloading.
Index: VirtualBox-6.0.0/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/GenVtf/GenVtf.h
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/GenVtf/GenVtf.h
+++ VirtualBox-6.0.0/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/GenVtf/GenVtf.h
@@ -102,7 +102,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF
//
#define UTILITY_MAJOR_VERSION 0
#define UTILITY_MINOR_VERSION 1
-#define UTILITY_DATE __DATE__
+#define UTILITY_DATE "no date"
//
// The maximum number of arguments accepted from the command line.
Index: VirtualBox-6.0.0/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/VolInfo/VolInfo.c
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/VolInfo/VolInfo.c
+++ VirtualBox-6.0.0/src/VBox/Devices/EFI/Firmware/BaseTools/Source/C/VolInfo/VolInfo.c
@@ -170,7 +170,7 @@ Returns:
UTILITY_MAJOR_VERSION,
UTILITY_MINOR_VERSION,
__BUILD_VERSION,
- __DATE__
+ "no date"
);
//
Index: VirtualBox-6.0.0/src/VBox/HostDrivers/VBoxUSB/win/dev/VBoxUsbDev.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/HostDrivers/VBoxUSB/win/dev/VBoxUsbDev.cpp
+++ VirtualBox-6.0.0/src/VBox/HostDrivers/VBoxUSB/win/dev/VBoxUsbDev.cpp
@@ -118,7 +118,7 @@ static NTSTATUS vboxUsbDdiAddDevice(PDRI
static VOID vboxUsbDdiUnload(PDRIVER_OBJECT pDriverObject)
{
RT_NOREF1(pDriverObject);
- LogRel(("VBoxUsb::DriverUnload. Built Date (%s) Time (%s)\n", __DATE__, __TIME__));
+ LogRel(("VBoxUsb::DriverUnload. Built Date (%s) Time (%s)\n", "no date", "no time"));
VBoxDrvToolStrFree(&g_VBoxUsbGlobals.RegPath);
vboxUsbRtGlobalsTerm();
@@ -274,7 +274,7 @@ RT_C_DECLS_END
NTSTATUS DriverEntry(IN PDRIVER_OBJECT pDriverObject, IN PUNICODE_STRING pRegistryPath)
{
- LogRel(("VBoxUsb::DriverEntry. Built Date (%s) Time (%s)\n", __DATE__, __TIME__));
+ LogRel(("VBoxUsb::DriverEntry. Built Date (%s) Time (%s)\n", "no date", "no time"));
NTSTATUS Status = vboxUsbRtGlobalsInit();
Assert(Status == STATUS_SUCCESS);
Index: VirtualBox-6.0.0/src/VBox/HostDrivers/VBoxUSB/win/mon/VBoxUsbMon.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/HostDrivers/VBoxUSB/win/mon/VBoxUsbMon.cpp
+++ VirtualBox-6.0.0/src/VBox/HostDrivers/VBoxUSB/win/mon/VBoxUsbMon.cpp
@@ -1936,7 +1936,7 @@ NTSTATUS _stdcall DriverEntry(PDRIVER_OB
RTLogDestinations(0, "debugger");
#endif
- LOGREL(("Built %s %s", __DATE__, __TIME__));
+ LOGREL(("Built %s %s", "no date", "no time"));
memset (&g_VBoxUsbMonGlobals, 0, sizeof (g_VBoxUsbMonGlobals));
#ifdef VBOX_USB3PORT
Index: VirtualBox-6.0.0/src/VBox/Main/glue/VBoxLogRelCreate.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Main/glue/VBoxLogRelCreate.cpp
+++ VirtualBox-6.0.0/src/VBox/Main/glue/VBoxLogRelCreate.cpp
@@ -61,7 +61,7 @@ static DECLCALLBACK(void) vboxHeaderFoot
#endif
"Log opened %s\n",
g_pszLogEntity, VBOX_VERSION_STRING, RTBldCfgRevision(),
- RTBldCfgTargetDotArch(), __DATE__, __TIME__, szTmp);
+ RTBldCfgTargetDotArch(), "no date", "no time", szTmp);
pfnLog(pReleaseLogger, "Build Type: %s\n", KBUILD_TYPE);
int vrc = RTSystemQueryOSInfo(RTSYSOSINFO_PRODUCT, szTmp, sizeof(szTmp));
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/pr/tests/depend.c
===================================================================
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/nsprpub/pr/tests/depend.c
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/nsprpub/pr/tests/depend.c
@@ -141,7 +141,7 @@ int main(int argc, char **argv)
{
PRIntn tab = 0;
const PRVersionInfo *info = DummyLibVersion();
- const char *buildDate = __DATE__, *buildTime = __TIME__;
+ const char *buildDate = "no date", *buildTime = "no time";
printf("Depend.c build time is %s %s\n", buildDate, buildTime);
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/profile_main.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/profile_main.cpp
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/profile_main.cpp
@@ -458,7 +458,7 @@ int
main()
{
- cout << "String performance profiling. Compiled " __DATE__ " " __TIME__ << endl;
+ cout << "String performance profiling. Compiled nodate no time" << endl;
#ifdef TEST_STD_STRING
cout << "Testing std::string." << endl;
#else
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/test_main.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/test_main.cpp
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/StringFactoringTests/test_main.cpp
@@ -425,7 +425,7 @@ int
main()
{
int tests_failed = 0;
- cout << "String unit tests. Compiled " __DATE__ " " __TIME__ << endl;
+ cout << "String unit tests. Compiled no date no time" << endl;
#if 0
{
Index: VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/TestCOMPtr.cpp
===================================================================
--- VirtualBox-6.0.0.orig/src/libs/xpcom18a4/xpcom/tests/TestCOMPtr.cpp
+++ VirtualBox-6.0.0/src/libs/xpcom18a4/xpcom/tests/TestCOMPtr.cpp
@@ -102,7 +102,7 @@ class test_message
public:
test_message()
{
- printf("BEGIN unit tests for |nsCOMPtr|, compiled " __DATE__ "\n");
+ printf("BEGIN unit tests for |nsCOMPtr|, compiled no date\n");
}
~test_message()
Index: VirtualBox-6.0.0/src/VBox/Additions/3D/mesa/mesa-17.3.9/src/util/build_id.c
===================================================================
--- VirtualBox-6.0.0.orig/src/VBox/Additions/3D/mesa/mesa-17.3.9/src/util/build_id.c
+++ VirtualBox-6.0.0/src/VBox/Additions/3D/mesa/mesa-17.3.9/src/util/build_id.c
@@ -29,9 +29,8 @@
#include "build_id.h"
-#ifndef NT_GNU_BUILD_ID
+#undef NT_GNU_BUILD_ID
#define NT_GNU_BUILD_ID 3
-#endif
#ifndef ElfW
#define ElfW(type) Elf_##type

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
Index: VirtualBox-6.0.0/src/VBox/Additions/linux/installer/vboxadd.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Additions/linux/installer/vboxadd.sh
+++ VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
--- VirtualBox-6.0.0.orig/src/VBox/Additions/linux/installer/vboxadd.sh
+++ VirtualBox-6.0.0/src/VBox/Additions/linux/installer/vboxadd.sh
@@ -26,11 +26,14 @@
# Provides: vboxadd
# Required-Start:
@ -18,7 +18,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
### END INIT INFO
## @todo This file duplicates a lot of script with vboxdrv.sh. When making
@@ -139,18 +142,9 @@ module_build_log()
@@ -141,18 +144,9 @@ module_build_log()
dev=/dev/vboxguest
userdev=/dev/vboxuser
@ -37,7 +37,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
running_vboxguest()
{
lsmod | grep -q "vboxguest[^_-]"
@@ -193,12 +187,6 @@ do_vboxguest_non_udev()
@@ -195,12 +189,6 @@ do_vboxguest_non_udev()
fail "Cannot create device $dev with major $maj and minor $min"
}
fi
@ -50,7 +50,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
if [ ! -c $userdev ]; then
maj=10
@@ -209,12 +197,6 @@ do_vboxguest_non_udev()
@@ -211,12 +199,6 @@ do_vboxguest_non_udev()
rmmod vboxguest 2>/dev/null
fail "Cannot create device $userdev with major $maj and minor $min"
}
@ -63,54 +63,29 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
fi
fi
}
@@ -224,9 +206,8 @@ start()
@@ -224,10 +206,9 @@ do_vboxguest_non_udev()
start()
{
begin "Starting."
# If we got this far assume that the slow set-up has been done.
QUICKSETUP=start
- if test -z "${INSTALL_NO_MODULE_BUILDS}"; then
- uname -r | grep -q -E '^2\.6|^3|^4' 2>/dev/null &&
- setup --quick
+ setup --quick
test -d /sys &&
- ps -A -o comm | grep -q '/*udevd$' 2>/dev/null ||
+ uname -r | grep -q -E '^2\.6|^3|^4' 2>/dev/null &&
+ ps -A -o comm | grep -q '/*udevd$' 2>/dev/null ||
no_udev=1
running_vboxguest || {
rm -f $dev || {
@@ -239,7 +220,7 @@ start()
$MODPROBE vboxguest >/dev/null 2>&1 || {
setup
- $MODPROBE vboxguest >/dev/null 2>&1 ||
+ $MODPROBE vboxguest >/dev/null 2>&1 || {
fail "modprobe vboxguest failed"
@@ -236,7 +217,7 @@ start()
rm -f $userdev || {
fail "Cannot remove $userdev"
}
- $MODPROBE vboxguest >/dev/null 2>&1 ||
+ $MODPROBE vboxguest >/dev/null 2>&1 || {
fail "modprobe vboxguest failed"
case "$no_udev" in 1)
@@ -284,7 +265,8 @@ start()
fi
if test -n "${setup_gl}"; then
mkdir -p /var/lib/VBoxGuestAdditions/lib
- ln -sf "${INSTALL_DIR}/lib/VBoxOGL.so" /var/lib/VBoxGuestAdditions/lib/libGL.so.1
+ ln -sf "/usr/lib64/VBoxOGL.so" /var/lib/VBoxGuestAdditions/lib/libGL.so.1
+ ln -sf "/usr/lib64/VBoxEGL.so" /var/lib/VBoxGuestAdditions/lib/libEGL.so.1
# SELinux for the OpenGL libraries, so that gdm can load them during the
# acceleration support check. This prevents an "Oh no, something has gone
# wrong!" error when starting EL7 guests.
@@ -295,6 +277,15 @@ start()
chcon -h -t lib_t "/var/lib/VBoxGuestAdditions/lib/libGL.so.1"
fi
echo "/var/lib/VBoxGuestAdditions/lib" > /etc/ld.so.conf.d/00vboxvideo.conf
+ # The above code will enable 3D acceleration for Gnome VM desktops. For Plasma 5 (KDE)
+ # VM's almost everything breaks. For that reason, acceleration MUST be disabled here.
+ # Gnome users that want this feature should delete the two 'rm' commands that follow.
+ # You will need to repeat this modification EVERY time the VirtualBox package is
+ # reinstalled
+ # Any KDE user that deletes the two 'rm' commands MUST know how to recover your sustem
+ # from a mode 3 boot. YOU HAVE BEEN WARNED.
+ rm /var/lib/VBoxGuestAdditions/lib/*
+ rm /etc/ld.so.conf.d/00vboxvideo.conf
fi
ldconfig
@@ -488,9 +479,9 @@ create_udev_rule()
sleep .5;;
@@ -434,9 +415,9 @@ create_udev_rule()
echo "KERNEL=${udev_fix}\"vboxuser\", NAME=\"vboxuser\", OWNER=\"vboxadd\", MODE=\"0666\"" >> /etc/udev/rules.d/60-vboxadd.rules
fi
}
@ -123,7 +98,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
# And a post-installation script for rebuilding modules when a new kernel
# is installed.
mkdir -p /etc/kernel/postinst.d /etc/kernel/prerm.d
@@ -521,20 +512,13 @@ shared_folder_setup()
@@ -467,20 +448,13 @@ shared_folder_setup()
## @todo It would be nicer if the kernel module just parsed parameters
# itself instead of needing a separate binary to do that.
ln -sf "${INSTALL_DIR}/other/mount.vboxsf" /sbin
@ -146,7 +121,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
export BUILD_TYPE
export USERNAME
@@ -551,16 +535,33 @@ setup()
@@ -517,16 +491,33 @@ setup()
shared_folder_setup
if running_vboxguest || running_vboxadd; then
info "Running kernel modules will not be replaced until the system is restarted"
@ -185,7 +160,7 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
depmod
# Remove old module sources
@@ -570,13 +571,14 @@ cleanup()
@@ -536,12 +527,13 @@ cleanup()
fi
# Clean-up X11-related bits
@ -193,7 +168,6 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
+ #/sbin/rcvboxadd-x11 cleanup
# Remove other files
rm /sbin/mount.vboxsf 2>/dev/null
- if test -z "${INSTALL_NO_MODULE_BUILDS}"; then
- rm -f /etc/kernel/postinst.d/vboxadd /etc/kernel/prerm.d/vboxadd
- rmdir -p /etc/kernel/postinst.d /etc/kernel/prerm.d 2>/dev/null
@ -202,12 +176,12 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd.sh
+ rm -f /etc/kernel/postinst.d/vboxadd /etc/kernel/prerm.d/vboxadd
+ rmdir -p /etc/kernel/postinst.d /etc/kernel/prerm.d 2>/dev/null
fi
rm /sbin/mount.vboxsf 2>/dev/null
rm /etc/udev/rules.d/60-vboxadd.rules 2>/dev/null
}
Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd-service.sh
Index: VirtualBox-6.0.0/src/VBox/Additions/linux/installer/vboxadd-service.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Additions/linux/installer/vboxadd-service.sh
+++ VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd-service.sh
--- VirtualBox-6.0.0.orig/src/VBox/Additions/linux/installer/vboxadd-service.sh
+++ VirtualBox-6.0.0/src/VBox/Additions/linux/installer/vboxadd-service.sh
@@ -26,7 +26,7 @@
# Provides: vboxadd-service
# Required-Start: vboxadd
@ -217,10 +191,10 @@ Index: VirtualBox-5.2.22/src/VBox/Additions/linux/installer/vboxadd-service.sh
# Default-Stop: 0 1 6
# X-Conflicts-With: systemd-timesyncd.service
# Description: VirtualBox Additions Service
Index: VirtualBox-5.2.22/src/VBox/Installer/linux/vboxautostart-service.sh
Index: VirtualBox-6.0.0/src/VBox/Installer/linux/vboxautostart-service.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Installer/linux/vboxautostart-service.sh
+++ VirtualBox-5.2.22/src/VBox/Installer/linux/vboxautostart-service.sh
--- VirtualBox-6.0.0.orig/src/VBox/Installer/linux/vboxautostart-service.sh
+++ VirtualBox-6.0.0/src/VBox/Installer/linux/vboxautostart-service.sh
@@ -23,7 +23,7 @@
# Provides: vboxautostart-service
# Required-Start: vboxdrv
@ -230,10 +204,10 @@ Index: VirtualBox-5.2.22/src/VBox/Installer/linux/vboxautostart-service.sh
# Default-Stop: 0 1 6
# Description: VirtualBox autostart service
### END INIT INFO
Index: VirtualBox-5.2.22/src/VBox/Installer/linux/vboxballoonctrl-service.sh
Index: VirtualBox-6.0.0/src/VBox/Installer/linux/vboxballoonctrl-service.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/Installer/linux/vboxballoonctrl-service.sh
+++ VirtualBox-5.2.22/src/VBox/Installer/linux/vboxballoonctrl-service.sh
--- VirtualBox-6.0.0.orig/src/VBox/Installer/linux/vboxballoonctrl-service.sh
+++ VirtualBox-6.0.0/src/VBox/Installer/linux/vboxballoonctrl-service.sh
@@ -23,7 +23,7 @@
# Provides: vboxballoonctrl-service
# Required-Start: vboxdrv
@ -243,10 +217,10 @@ Index: VirtualBox-5.2.22/src/VBox/Installer/linux/vboxballoonctrl-service.sh
# Default-Stop: 0 1 6
# Description: VirtualBox watchdog daemon
### END INIT INFO
Index: VirtualBox-5.2.22/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
Index: VirtualBox-6.0.0/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
+++ VirtualBox-5.2.22/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
--- VirtualBox-6.0.0.orig/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
+++ VirtualBox-6.0.0/src/VBox/ValidationKit/testboxscript/linux/testboxscript-service.sh
@@ -31,7 +31,7 @@
# Provides: testboxscript-service
# Required-Start: $network
@ -256,10 +230,10 @@ Index: VirtualBox-5.2.22/src/VBox/ValidationKit/testboxscript/linux/testboxscrip
# Default-Stop: 0 1 6
# Description: TestBoxScript service
### END INIT INFO
Index: VirtualBox-5.2.22/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
Index: VirtualBox-6.0.0/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
+++ VirtualBox-5.2.22/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
--- VirtualBox-6.0.0.orig/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
+++ VirtualBox-6.0.0/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs-nat.sh
@@ -31,7 +31,7 @@
# Provides: vboxtxs
# Required-Start: $network
@ -269,10 +243,10 @@ Index: VirtualBox-5.2.22/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs
# Default-Stop: 0 1 6
# Description: VirtualBox Test Execution Service
### END INIT INFO
Index: VirtualBox-5.2.22/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
Index: VirtualBox-6.0.0/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
===================================================================
--- VirtualBox-5.2.22.orig/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
+++ VirtualBox-5.2.22/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
--- VirtualBox-6.0.0.orig/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
+++ VirtualBox-6.0.0/src/VBox/ValidationKit/utils/TestExecServ/linux/vboxtxs.sh
@@ -31,7 +31,7 @@
# Provides: vboxtxs
# Required-Start: $network

View File

@ -1,7 +1,7 @@
Index: VirtualBox-5.2.14/src/VBox/Installer/linux/vboxdrv.sh
Index: VirtualBox-6.0.0/src/VBox/Installer/linux/vboxdrv.sh
===================================================================
--- VirtualBox-5.2.14.orig/src/VBox/Installer/linux/vboxdrv.sh
+++ VirtualBox-5.2.14/src/VBox/Installer/linux/vboxdrv.sh
--- VirtualBox-6.0.0.orig/src/VBox/Installer/linux/vboxdrv.sh
+++ VirtualBox-6.0.0/src/VBox/Installer/linux/vboxdrv.sh
@@ -19,11 +19,12 @@
#
### BEGIN INIT INFO
@ -33,7 +33,7 @@ Index: VirtualBox-5.2.14/src/VBox/Installer/linux/vboxdrv.sh
if ! $MODPROBE vboxnetflt > /dev/null 2>&1; then
failure "modprobe vboxnetflt failed. Please use 'dmesg' to find out why"
fi
@@ -420,47 +414,8 @@ cleanup()
@@ -421,48 +415,8 @@ cleanup()
# setup_script
setup()
{
@ -77,6 +77,7 @@ Index: VirtualBox-5.2.14/src/VBox/Installer/linux/vboxdrv.sh
- fi
- rm -f /etc/vbox/module_not_compiled
- depmod -a
- sync
- succ_msg "VirtualBox kernel modules built"
+# Try to build the host kernel modules in case prepackaging has failed
+ /sbin/vboxconfig

View File

@ -1,14 +0,0 @@
Index: VirtualBox-5.2.0/src/VBox/Installer/linux/vboxweb-service.sh
===================================================================
--- VirtualBox-5.2.0.orig/src/VBox/Installer/linux/vboxweb-service.sh
+++ VirtualBox-5.2.0/src/VBox/Installer/linux/vboxweb-service.sh
@@ -20,7 +20,7 @@
# Provides: vboxweb-service
# Required-Start: vboxdrv
# Required-Stop: vboxdrv
-# Default-Start: 2 3 4 5
+# Default-Start: 2 3 5
# Default-Stop: 0 1 6
# Description: VirtualBox web service API
### END INIT INFO

View File

@ -450,3 +450,4 @@ status)
esac
exit 0

20
vboxweb-service.service Normal file
View File

@ -0,0 +1,20 @@
[Unit]
SourcePath=/usr/lib/virtualbox/vboxweb-service.sh
Description=
Before=runlevel2.target runlevel3.target runlevel4.target runlevel5.target shutdown.target
After=vboxdrv.service
Conflicts=shutdown.target
[Service]
Type=forking
Restart=no
TimeoutSec=5min
IgnoreSIGPIPE=no
KillMode=process
GuessMainPID=no
RemainAfterExit=yes
ExecStart=/usr/lib/virtualbox/vboxweb-service.sh start
ExecStop=/usr/lib/virtualbox/vboxweb-service.sh stop
[Install]
WantedBy=multi-user.target

225
vboxweb-service.sh Normal file
View File

@ -0,0 +1,225 @@
#!/bin/sh
# $Id: vboxweb-service.sh 127855 2019-01-01 01:45:53Z bird $
## @file
# VirtualBox web service API daemon init script.
#
#
# Copyright (C) 2006-2019 Oracle Corporation
#
# This file is part of VirtualBox Open Source Edition (OSE), as
# available from http://www.virtualbox.org. This file is free software;
# you can redistribute it and/or modify it under the terms of the GNU
# General Public License (GPL) as published by the Free Software
# Foundation, in version 2 as it comes in the "COPYING" file of the
# VirtualBox OSE distribution. VirtualBox OSE is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
#
# chkconfig: 345 35 65
# description: VirtualBox web service API
#
### BEGIN INIT INFO
# Provides: vboxweb-service
# Required-Start: vboxdrv
# Required-Stop: vboxdrv
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Description: VirtualBox web service API
### END INIT INFO
PATH=$PATH:/bin:/sbin:/usr/sbin
SCRIPTNAME=vboxweb-service.sh
[ -f /etc/vbox/vbox.cfg ] && . /etc/vbox/vbox.cfg
if [ -n "$INSTALL_DIR" ]; then
binary="$INSTALL_DIR/vboxwebsrv"
vboxmanage="$INSTALL_DIR/VBoxManage"
else
binary="/usr/lib/virtualbox/vboxwebsrv"
vboxmanage="/usr/lib/virtualbox/VBoxManage"
fi
# silently exit if the package was uninstalled but not purged,
# applies to Debian packages only (but shouldn't hurt elsewhere)
[ ! -f /etc/debian_release -o -x $binary ] || exit 0
[ -r /etc/default/virtualbox ] && . /etc/default/virtualbox
PIDFILE="/var/run/${SCRIPTNAME}"
# Preamble for Gentoo
if [ "`which $0`" = "/sbin/rc" ]; then
shift
fi
begin_msg()
{
test -n "${2}" && echo "${SCRIPTNAME}: ${1}."
logger -t "${SCRIPTNAME}" "${1}."
}
succ_msg()
{
logger -t "${SCRIPTNAME}" "${1}."
}
fail_msg()
{
echo "${SCRIPTNAME}: failed: ${1}." >&2
logger -t "${SCRIPTNAME}" "failed: ${1}."
}
start_daemon() {
usr="$1"
shift
su - $usr -c "$*"
}
killproc() {
killall $1
rm -f $PIDFILE
}
if which start-stop-daemon >/dev/null 2>&1; then
start_daemon() {
usr="$1"
shift
bin="$1"
shift
start-stop-daemon --background --chuid $usr --start --exec $bin -- $@
}
killproc() {
start-stop-daemon --stop --exec $@
}
fi
vboxdrvrunning() {
lsmod | grep vboxdrv
}
check_single_user() {
if [ -n "$2" ]; then
fail_msg "VBOXWEB_USER must not contain multiple users!"
exit 1
fi
}
start() {
if ! test -f $PIDFILE; then
[ -z "$VBOXWEB_USER" ] && exit 0
begin_msg "Starting VirtualBox web service" console;
check_single_user $VBOXWEB_USER
temp=$(lsmod | grep vboxdrv)
echo $temp
if [ -z "$temp" ]; then
fail_msg "VirtualBox kernel module not loaded!"
--- VirtualBox-6.0.0.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
+++ VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -251,15 +251,15 @@ void UINameAndSystemEditor::sltFamilyCha
if (iIndexWin7 != -1)
m_pComboType->setCurrentIndex(iIndexWin7);
}
/* Or select Ubuntu item for Linux family as default: */
/* Or select Oracle Linux item for Linux family as default: */
else if (strFamilyId == "Linux")
else if (m_strFamilyId == "Linux")
{
- QString strDefaultID = "Ubuntu";
- QString strDefaultID = "Oracle";
+ QString strDefaultID = "openSUSE";
if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
strDefaultID += "_64";

View File

@ -1,7 +1,7 @@
@@ -251,15 +251,15 @@ void UINameAndSystemEditor::sltFamilyCha
m_pComboType->setCurrentIndex(iIndexWin7);
}
- /* Or select Ubuntu item for Linux family as default: */
- /* Or select Oracle Linux item for Linux family as default: */
+ /* Or select openSUSE item for Linux family as default: */
else if (strFamilyId == "Linux")
else if (m_strFamilyId == "Linux")